class ToolVariables:
    @classmethod
    def ExcheckUpdate(cls):
        cls.INTAG = "ExCheck"
        return cls

